@@ -5,10 +5,14 @@ Classes for exporting associations.
 import re
 import datetime
 import json
+import logging
 
 from typing import List
 
 from ontobio import ecomap
+from ontobio.io import assocparser
+
+logger = logging.getLogger(__name__)
 
 external_taxon = re.compile("taxon:([0-9]+)")
 internal_taxon = re.compile("NCBITaxon:([0-9]+)")
@@ -40,7 +44,7 @@ class AssocWriter():
             self.file.write(line+"\n")
         else:
             print(line)
-            
+
     def tsv_as_string(self, vals) -> str:
         return "\t".join([_str(v) for v in vals])
 
@@ -86,7 +90,7 @@ class AssocWriter():
             return "taxon:{num}".format(num=taxon_id)
 
         return taxon
-        
+
     def as_tsv(self, assoc) -> List[str]:
         """
         Transform a single association to a string line.
@@ -172,11 +176,36 @@ class GpadWriter(AssocWriter):
 
 class GafWriter(AssocWriter):
     """
-    Writes Associations in GAF format. Not yet implemented
+    Writes Associations in GAF format.
+
+    This converts an association dictionary object as produced in GafParser or
+    GpadParser into a GAF line.
+
+    The GAF Writer now assumes that it is writing out GAF version 2.1 style
+    annotations. The version can be set when creating a new GafWriter to 2.2
+    with `version=2.2`. If any version other than 2.1 or 2.2, GafWriter will
+    default to 2.1.
+
+    The only difference in 2.1 and 2.2 are how qualifiers (column 4) are handled.
+    GAF 2.1 allows empty or only `NOT` qualifier values, and only allows
+    `colocalizes_with` and `contributes_to` as qualifer values. However in 2.2
+    qualifier must *not* be empty and cannot have only `NOT` as it's a modifier
+    on existing qualifers. The set of allowed qualifiers in 2.2 is also expanded.
+
+    So if there's a mismatch between converting from an annotation and a GAF
+    version then that annotation is just skipped and not written out with an
+    error message displayed. Mismatch occurances of this kind would appear if
+    the incoming annotation has a qualifier in the 2.2 set, but 2.1 is being
+    written out, or if the qualifier is empty and 2.2 is being written.
     """
-    def __init__(self, file=None, source=None):
+    def __init__(self, file=None, source=None, version="2.1"):
         self.file = file
-        self._write("!gaf-version: 2.1\n")
+        if version not in ["2.1", "2.2"]:
+            self.version = "2.1"
+        else:
+            self.version = version
+
+        self._write("!gaf-version: {}\n".format(version))
         self._write("!\n")
         self._write("!Generated by GO Central\n")
         self._write("!\n")
@@ -201,7 +230,7 @@ class GafWriter(AssocWriter):
         if assoc.get("header", False):
 
             # Skip incoming gaf-version headers, as we created the version above already
-            if re.match("![\s]*gaf.?version", assoc["line"]):
+            if assocparser.parser_version_regex.match(assoc["line"]):
                 return []
 
             self._write(assoc["line"] + "\n")
@@ -212,10 +241,24 @@ class GafWriter(AssocWriter):
 
         db, db_object_id = self._split_prefix(subj)
 
-        qualifier = "|".join(assoc["qualifiers"])
-        # qualifier is | seperated string, filter on None removes empty strings in case qualifiers is empty
-        if assoc['negated']:
-            qualifier = "|".join(list(filter(None, ["NOT", qualifier])))
+        qual_negated = ["NOT"] if assoc["negated"] else []
+        qualifier = ""
+        if self.version == "2.1":
+            allowed_qualifiers = {"contributes_to", "colocalizes_with"}
+            # Detect if the qualifier is wrong
+            if len(assoc["qualifiers"]) == 1 and assoc["qualifiers"][0] not in allowed_qualifiers:
+                logger.error("Cannot write qualifier `{}` in GAF version 2.1 since only {} are allowed: skipping".format(assoc["qualifers"][0]), ", ".join(allowed_qualifiers))
+                return []
+
+        else:
+            # Then we're 2.2
+            if len(assoc["qualifiers"]) == 0:
+                logger.error("Qualifier must not be empty for GAF version 2.2")
+                return []
+
+        # assoc["qualifiers"] is appropriately set up for whatever version this is
+        quals = qual_negated + assoc["qualifiers"]
+        qualifier = "|".join(quals)
 
         goid = assoc['object']['id']
 
