@@ -3,13 +3,14 @@ import typing
 import collections
 import enum
 import datetime
+import re
 
 from ontobio.ecomap import EcoMap
 ecomap = EcoMap()
 ecomap.mappings()
 
 
-from typing import List, Optional, NamedTuple, Dict, Callable
+from typing import List, Optional, NamedTuple, Dict, Callable, Union, TypeVar
 from dataclasses import dataclass
 
 Aspect = typing.NewType("Aspect", str)
@@ -31,39 +32,81 @@ class Term:
     id: Curie
     taxon: Curie
 
+C = TypeVar("C")
+
+@dataclass
+class Error:
+    info: str
+
+@dataclass(unsafe_hash=True)
+class ConjunctiveSet:
+    elements: List
+
+    def __str__(self) -> str:
+        return ",".join([str(conj) for conj in self.elements])
+
+    @classmethod
+    def list_to_str(ConjunctiveSet, conjunctions: List) -> str:
+        """
+        List should be a list of ConjunctiveSet
+        """
+        return "|".join([str(conj) for conj in conjunctions])
+
+    @classmethod
+    def str_to_conjunctions(ConjunctiveSet, entity: str, conjunct_element_builder: Union[C, Error]=lambda el: str(el)) -> Union[List[C], Error]:
+        """
+        Takes a field that conforms to the pipe (|) and comma (,) separator type. The parsed version is a list of pipe separated values
+        which are themselves a comma separated list.
+
+        If the elements inside the comma separated list should not just be strings, but be converted into a value of a type, `conjunct_element_builder` can be provided which should take a string and return a parsed value or an instance of an Error type (defined above).
+
+        If there is an error in producing the values of the conjunctions, then this function will return early with the error.
+
+        This function will return a List of ConjunctiveSet
+        """
+        conjunctions = []
+        for conj in filter(None, entity.split("|")):
+            conjunct = []
+            for el in filter(None, conj.split(",")):
+                built = conjunct_element_builder(el)
+                if isinstance(built, Error):
+                    # Returning an Error instance
+                    return built
+
+                conjunct.append(built)
+
+            conjunctions.append(ConjunctiveSet(conjunct))
+
+        return conjunctions
+
 @dataclass
 class Evidence:
     type: Curie # Curie of the ECO class
     has_supporting_reference: List[Curie]
-    with_support_from: List[Curie]
+    with_support_from: List[ConjunctiveSet]
+
+relation_tuple = re.compile(r'(.+)\((.+)\)')
 
 @dataclass(unsafe_hash=True)
 class ExtensionUnit:
     relation: Curie
     term: Curie
 
+    @classmethod
+    def from_str(ExtensionUnit, entity: str) -> Union:
+        """
+        Attempts to parse string entity as an ExtensionUnit
+        """
+        parsed = relation_tuple.findall(entity)
+        if len(parsed) == 1:
+            rel, term = parsed[0]
+            return ExtensionUnit(rel, term)
+        else:
+            return Error(entity)
+
     def __str__(self) -> str:
         return "{relation}({term})".format(relation=self.relation, term=self.term)
 
-@dataclass(unsafe_hash=True)
-class ExtensionConjunctions:
-    extensions: List[ExtensionUnit]
-
-    def __str__(self) -> str:
-        return ",".join([str(conj) for conj in self.extensions])
-
-@dataclass
-class ExtensionExpression:
-    """
-    ExtensionExpression ::= ConjunctionExpression { "|" ConjunctionExpression }
-    ConjunctionExpression ::= ExtensionUnit { "," ExtensionUnit }
-    ExtensionUnit ::= Relation "(" Term ")"
-    """
-    conjunctions: List[ExtensionConjunctions]
-
-    def __str__(self) -> str:
-        return "|".join([str(conjunction) for conjunction in self.conjunctions])
-
 @dataclass(repr=True, unsafe_hash=True)
 class GoAssociation:
     source_line: Optional[str]
@@ -76,7 +119,7 @@ class GoAssociation:
     interacting_taxon: Optional[Curie]
     evidence: Evidence
     subject_extensions: List[ExtensionUnit]
-    object_extensions: ExtensionExpression
+    object_extensions: List[ConjunctiveSet]
     provided_by: Provider
     date: Date
     properties: Dict[Curie, List[str]]
@@ -102,7 +145,7 @@ class GoAssociation:
             self.object.id,
             "|".join(self.evidence.has_supporting_reference),
             ecomap.ecoclass_to_coderef(self.evidence.type)[0],
-            "|".join(self.evidence.with_support_from),
+            ConjunctiveSet.list_to_str(self.evidence.with_support_from),
             self.aspect if self.aspect else "",
             self.subject.fullname,
             "|".join(self.subject.synonyms),
@@ -110,7 +153,7 @@ class GoAssociation:
             taxon,
             self.date,
             self.provided_by,
-            str(self.object_extensions),
+            ConjunctiveSet.list_to_str(self.object_extensions),
             gp_isoforms
         ]
 
@@ -131,10 +174,10 @@ class GoAssociation:
             self.object.id,
             "|".join(self.evidence.has_supporting_reference),
             self.evidence.type,
-            "|".join(self.evidence.with_support_from),
+            ConjunctiveSet.list_to_str(self.evidence.with_support_from),
             self.interacting_taxon if self.interacting_taxon else "",
             self.date,
             self.provided_by,
-            str(self.object_extensions),
+            ConjunctiveSet.list_to_str(self.object_extensions),
             "|".join(props_list)
         ]
